Value

Enum Value 

#[non_exhaustive]
pub enum Value {
Show 18 variants Byte(u8), Short(u16), SignedByte(i8), SignedShort(i16), Signed(i32), SignedBig(i64), Unsigned(u32), UnsignedBig(u64), Float(f32), Double(f64), List(Vec<Value>), Rational(u32, u32), RationalBig(u64, u64), SRational(i32, i32), SRationalBig(i64, i64), Ascii(String), Ifd(u32), IfdBig(u64),
}

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Byte(u8)



Short(u16)



SignedByte(i8)



SignedShort(i16)



Signed(i32)



SignedBig(i64)



Unsigned(u32)



UnsignedBig(u64)



Float(f32)



Double(f64)



List(Vec<Value>)



Rational(u32, u32)



RationalBig(u64, u64)

👎Deprecated since 0.11.1: Not implemented in BigTIFF with a standard tag value


SRational(i32, i32)



SRationalBig(i64, i64)

👎Deprecated since 0.11.1: Not implemented in BigTIFF with a standard tag value


Ascii(String)



Ifd(u32)



IfdBig(u64)

Implementations

Source

impl Value

pub fn into_u8(self) -> TiffResult<u8>

pub fn into_i8(self) -> TiffResult<i8>

pub fn into_u16(self) -> TiffResult<u16>

pub fn into_i16(self) -> TiffResult<i16>

pub fn into_u32(self) -> TiffResult<u32>

pub fn into_i32(self) -> TiffResult<i32>

pub fn into_u64(self) -> TiffResult<u64>

pub fn into_i64(self) -> TiffResult<i64>

pub fn into_f32(self) -> TiffResult<f32>

pub fn into_f64(self) -> TiffResult<f64>

pub fn into_ifd_pointer(self) -> TiffResult<IfdPointer>

Turn this value into an IfdPointer.

Notice that this does not take an argument, a 64-bit IFD is always allowed. If the difference is crucial and you do not want to be permissive you’re expected to filter this out before.

For compatibility the smaller sized tags should always be allowed i.e. you might use a non-bigtiff’s directory and its tag types and move it straight to a bigtiff. For instance the SubIFD tag is defined as LONG or IFD:

https://web.archive.org/web/20181105221012/https://www.awaresystems.be/imaging/tiff/tifftags/subifds.html

pub fn into_string(self) -> TiffResult<String>

pub fn into_u32_vec(self) -> TiffResult<Vec<u32>>

pub fn into_u8_vec(self) -> TiffResult<Vec<u8>>

pub fn into_u16_vec(self) -> TiffResult<Vec<u16>>

pub fn into_i32_vec(self) -> TiffResult<Vec<i32>>

pub fn into_f32_vec(self) -> TiffResult<Vec<f32>>

pub fn into_f64_vec(self) -> TiffResult<Vec<f64>>

pub fn into_u64_vec(self) -> TiffResult<Vec<u64>>

pub fn into_i64_vec(self) -> TiffResult<Vec<i64>>

pub fn into_ifd_vec(self) -> TiffResult<Vec<IfdPointer>>