#[non_exhaustive]pub struct Limits {
pub decoding_buffer_size: usize,
pub ifd_value_size: usize,
pub intermediate_buffer_size: usize,
}Expand description
Decoding limits
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.decoding_buffer_size: usizeThe maximum size of any DecodingResult in bytes, the default is
256MiB. If the entire image is decoded at once, then this will
be the maximum size of the image. If it is decoded one strip at a
time, this will be the maximum size of a strip.
ifd_value_size: usizeThe maximum size of any ifd value in bytes, the default is 1MiB.
intermediate_buffer_size: usizeMaximum size for intermediate buffer which may be used to limit the amount of data read per segment even if the entire image is decoded at once.
Implementations
Sourceimpl Limits
impl Limits
Sourcepub fn unlimited() -> Limits
pub fn unlimited() -> Limits
A configuration that does not impose any limits.
This is a good start if the caller only wants to impose selective limits, contrary to the default limits which allows selectively disabling limits.
Note that this configuration is likely to crash on excessively large images since, naturally, the machine running the program does not have infinite memory.