pub struct Ifd8(pub u64);Expand description
Type to represent tiff values of type IFD8
Tuple Fields
0: u64Trait Implementations
sourceimpl TiffValue for Ifd8
impl TiffValue for Ifd8
const BYTE_LEN: u8 = 8u8
const FIELD_TYPE: Type = Type::IFD8
fn count(&self) -> usize
sourcefn write<W: Write>(&self, writer: &mut TiffWriter<W>) -> TiffResult<()>
fn write<W: Write>(&self, writer: &mut TiffWriter<W>) -> TiffResult<()>
Write this value to a TiffWriter.
While the default implementation will work in all cases, it may require unnecessary allocations.
The written bytes of any custom implementation MUST be the same as yielded by self.data(). Read more
sourcefn data(&self) -> Cow<'_, [u8]>
fn data(&self) -> Cow<'_, [u8]>
Access this value as an contiguous sequence of bytes. If their is no trivial representation, allocate it on the heap. Read more
fn bytes(&self) -> usize